input

Function input 

pub fn input(request: &str, options: InputOptions) -> Result<()>
This is essentially the \input equivalent

we are most likely expecting to get actual content, (possibly with definitions included, as well) but might actually be getting pure definitions, (like a proper style file) in which case we may really want to load a binding. Note that generic style files (non-latex) often have a .tex extension.