input_content

Function input_content 

pub fn input_content(request: &str, options: InputOptions) -> Result<()>
Input for cases when the file (or data) is plain TeX material that is expected to contribute content to the document (as opposed to pure definitions).

A Mouth is opened onto the file, and subsequent reading and/or digestion will pull Tokens from that Mouth until it is exhausted, or closed.

In some circumstances it may be useful to provide a string containing the TeX material explicitly, rather than referencing a file. In this case, the literal pseudo-protocal may be used.