require_package

Function require_package 

pub fn require_package(name: &str, options: RequireOptions) -> Result<()>
An opinionated binding for \RequirePackage.

This (and FindFile) needs to evolve a bit to support reading raw .sty (.def, etc) files from the standard texmf directories. Maybe even use kpsewhich itself (INSTEAD of pathname_find ???) Another potentially useful option might be that if we are reading a raw file, perhaps it should just get digested immediately, since it shouldn’t contribute any boxes.