pub fn font_decode_string(
string: &str,
encoding_opt: Option<&str>,
implicit: bool,
) -> StringExpand description
Decode a string using the fontmap for a given encoding (Perl: FontDecodeString).
If implicit is true, codepoints missing from the map decode to themselves.