pub struct InputDefinitionOptions {Show 13 fields
pub extension: Option<Cow<'static, str>>,
pub options: Vec<String>,
pub after: Tokens,
pub notex: bool,
pub noerror: bool,
pub noltxml: bool,
pub withoptions: Option<Vec<String>>,
pub handleoptions: bool,
pub as_class: bool,
pub raw: bool,
pub reloadable: bool,
pub at_letter: bool,
pub searchpaths_only: bool,
}Expand description
a configuration for loading LaTeX definition files (such as .sty, .cls, and their bindings)
Fields
extension: Option<Cow<'static, str>>an optional extension (such as “sty”)
options: Vec<String>package options to pass into the loaded library
after: TokensTokens to process after the definition is loaded
notex: boolflag to forbid raw TeX sources
noerror: boolflag to forbid errors ?
noltxml: boolflag to forbid binding dispatch
withoptions: Option<Vec<String>>collection of (package) options to process when loading the dependency
handleoptions: boolflag to handle options, or ignore them
as_class: boolflag to process in .cls mode (default: false)
raw: boolflag to indicate reading the file raw in Gullet
reloadable: boolflag to allow reloading a previously loaded definitions file
at_letter: boolflag: set @ catcode to LETTER during loading (default true). Set to false for packages like xy.tex that need @ to stay as OTHER.
searchpaths_only: boolWhen set, raw-file lookup is restricted to the user-supplied
SEARCHPATHS (SOURCEDIRECTORY + graphicspaths), skipping the
kpsewhich fallback into system texmf. Matches Perl Package.pm’s
searchpaths_only => 1 — enabled by the localrawstyles option
to latexml.sty. Perl ref: Package.pm L2135, L2674.